# Attributions

All modifications to the listed assets, unless stated otherwise, involve non-destructive transformations, mesh simplification, conversion to the [Universal Scene Description (USD)](https://openusd.org) format, rigging, and application of USD APIs for integration purposes.

1. **[Mars Perseverance Rover, 3D Model](https://science.nasa.gov/resource/mars-perseverance-rover-3d-model)** by NASA.
1. **[Mars Ingenuity Helicopter, 3D Model](https://science.nasa.gov/resource/mars-ingenuity-helicopter-3d-model)** by NASA.
1. **[Mars 2020 Sample Tube, 3D Model](https://github.com/nasa/NASA-3D-Resources/blob/8780ccf7afd4e6dcdd9c0bed313354173dcd924f/3D%20Models/Mars%202020%20Sample%20Tube%203D%20print%20files/SAMPLE_TUBE.STL)** by NASA. This mesh was modified to include a cap, and additional materials were added.
1. **[Gateway Core, 3D Model](https://nasa3d.arc.nasa.gov/detail/gateway)** by NASA. The model was separated into individual assets: Canadarm3 (small and large) and the Gateway Core itself.
1. **[Low Lunar Orbit, HDR Image](https://nasa3d.arc.nasa.gov/detail/gateway)** by NASA. This image was rotated by 90 degrees to better align with the implemented environment.
1. **[Lunar Rover from the Movie *Moon*, 3D Model](https://skfb.ly/owELz)** by Watndit, licensed under [Creative Commons Attribution](http://creativecommons.org/licenses/by/4.0). The original model was heavily remodelled and retextured, with significant parts of the geometry removed. The wheels were replaced with a model from NASA's [Curiosity Rover, 3D Model](https://science.nasa.gov/resource/curiosity-rover-3d-model).
